Supporting classes
---------------------------------

The Metadata API includes multiple classes that are used by the top-level
ones (Root, Timestamp, Snapshot, Targets):

.. autosummary::
   :nosignatures:

   tuf.api.metadata.DelegatedRole
   tuf.api.metadata.Delegations
   tuf.api.metadata.Key
   tuf.api.metadata.MetaFile
   tuf.api.metadata.Role
   tuf.api.metadata.TargetFile
   tuf.api.metadata.SuccinctRoles

.. autoclass:: tuf.api.metadata.DelegatedRole

.. autoclass:: tuf.api.metadata.Delegations

.. autoclass:: tuf.api.metadata.Key

.. autoclass:: tuf.api.metadata.MetaFile

.. autoclass:: tuf.api.metadata.Role

.. autoclass:: tuf.api.metadata.TargetFile

.. autoclass:: tuf.api.metadata.SuccinctRoles